@@ -197,6 +197,7 @@ def n_largest_by_category(
         category_values = {i for i in cat[category].value_counts().index if i == i}
         samples_as_categories = False
 
+    str_samples = ""  # This is just to suppress compiler warnings
     # parsing categories
     for value in category_values:
         if samples_as_categories:
@@ -206,7 +207,6 @@ def n_largest_by_category(
             grouped_df = cat[cat[category] == value][asvs].astype("float")
             grouped_counts = grouped_df.sum().nlargest(n)
             str_samples = " ".join(i for i in grouped_df.index if i in samples)
-            grouped_df["samples"] = str_samples  # add a column with sample names
 
         grouped_counts = grouped_counts[
             grouped_counts > 0
@@ -216,6 +216,8 @@ def n_largest_by_category(
         grouped_df = grouped_df[tax_columns].copy()
         grouped_df["counts"] = grouped_counts
         grouped_df[category] = value
+        if not samples_as_categories:
+            grouped_df["samples"] = str_samples
         nlargest[value] = grouped_df
 
     cat_df = pd.concat((v for k, v in nlargest.items()))
@@ -260,8 +262,8 @@ def blastn(query, db, params, _print=True):
     :return:
     """
     blastn_bin = getoutput("which blastn")
-    assert (
-        "command not found" not in blastn_bin
+    assert all(
+        ("command not found" not in blastn_bin, blastn_bin != "")
     ), "Could not find blastn. Make sure blastn is on $PATH."
     assert path.isfile(db), "Could not find db {}. Make sure db exists".format(db)
     output_file, _ = path.splitext(query)
@@ -435,16 +437,67 @@ def fetch_ncbi_information(
                 .iloc[:, 0]
             )
 
-    # Sorting columns for output
     new_cols = [
-        i for i in asv_table_with_neighbors_and_ncbi.columns if "cultured" not in i
+        "ASV_ID",
+        "Taxon",
+        "Confidence",
+        "domain",
+        "phylum",
+        "class",
+        "order",
+        "family",
+        "genus",
+        "species",
+        "counts",
+        "cultured_accession",
+        "cultured_fmt_accession",
+        "cultured_bitscore",
+        "cultured_evalue",
+        "cultured_gapopen",
+        "cultured_pident",
+        "cultured_qstart",
+        "cultured_qend",
+        "cultured_sstart",
+        "cultured_send",
+        "cultured_length",
+        "cultured_mismatch",
+        "cultured_sseqid",
+        "cultured_taxonomy",
+        "cultured_domain",
+        "cultured_phylum",
+        "cultured_class",
+        "cultured_order",
+        "cultured_family",
+        "cultured_genus",
+        "cultured_species",
+        "cultured_isolation_source",
+        "cultured_host",
+        "uncultured_accession",
+        "uncultured_fmt_accession",
+        "uncultured_bitscore",
+        "uncultured_evalue",
+        "uncultured_gapopen",
+        "uncultured_pident",
+        "uncultured_qstart",
+        "uncultured_qend",
+        "uncultured_sstart",
+        "uncultured_send",
+        "uncultured_length",
+        "uncultured_mismatch",
+        "uncultured_sseqid",
+        "uncultured_taxonomy",
+        "uncultured_domain",
+        "uncultured_phylum",
+        "uncultured_class",
+        "uncultured_order",
+        "uncultured_family",
+        "uncultured_genus",
+        "uncultured_species",
+        "uncultured_isolation_source",
+        "uncultured_host",
+        "samples",
     ]
-    culture_cols = [
-        i for i in asv_table_with_neighbors_and_ncbi.columns if "cultured" in i
-    ]
-    culture_cols.sort()
-    for item in culture_cols:
-        new_cols.append(item)
+
     asv_table_with_neighbors_and_ncbi = asv_table_with_neighbors_and_ncbi[new_cols]
 
     return asv_table_with_neighbors_and_ncbi
@@ -521,7 +574,14 @@ def get_neighbors(seqid, blast_output_df):
         uncul = pd.Series(dtype="object")
 
     try:
-        cul = df_seqid[~df_seqid["stitle"].str.contains("uncultured")].iloc[0].copy()
+        cul = (
+            df_seqid[
+                ~(df_seqid["stitle"].str.contains("uncultured"))
+                & ~(df_seqid["stitle"].str.contains("metagenome"))
+            ]
+            .iloc[0]
+            .copy()
+        )
     except IndexError:
         cul = pd.Series(dtype="object")
 
@@ -529,7 +589,7 @@ def get_neighbors(seqid, blast_output_df):
         if not series.empty:
             series["accession"], series["taxonomy"] = (
                 series["stitle"].split()[0],
-                series["stitle"].split()[1],
+                " ".join(series["stitle"].split()[1:]),
             )
             series["fmt_accession"] = series["accession"].split(".")[0] + ".1"
             for ix, rank in enumerate(
@@ -594,22 +654,28 @@ def add_neighbors_to_asv_table(asv_table, blast_out, _print=True):
         for col in col_list:
             asv_table[col] = ""
 
+    def get_row(dict_, row_, kind, column_):
+        """
+        Extracts row from ASV table
+        :param dict_: Dict of cultured or uncultured neighbors
+        :param row_: name of column to add to ASV table
+        :param kind: cultured_ or uncultured_
+        :param column_: column of ASV table to update
+        :return: value to add to ASV table
+        """
+        try:
+            output = dict_[row_.iloc[0]].loc[str(column_).replace(kind, "")]
+        except KeyError:
+            output = ""
+
+        return output
+
     # Iterate rows and add neighbor values
     for ix, row in asv_table.iterrows():
         for column in row.index:
             if column in cul_cols:
-                try:
-                    asv_table.loc[ix, column] = cul[row.iloc[0]].loc[
-                        str(column).replace("cultured_", "")
-                    ]
-                except KeyError:
-                    asv_table.loc[ix, column] = ""
+                asv_table.loc[ix, column] = get_row(cul, row, "cultured_", column)
             elif column in uncul_cols:
-                try:
-                    asv_table.loc[ix, column] = uncul[row.iloc[0]].loc[
-                        str(column).replace("uncultured_", "")
-                    ]
-                except KeyError:
-                    asv_table.loc[ix, column] = ""
+                asv_table.loc[ix, column] = get_row(uncul, row, "uncultured_", column)
 
     return asv_table
